# the future isn't centralized, it's personalized

srswti-axis (AI eXplainable Inference & Search) is an industry-ready machine learning library for advanced data retrieval and interpretable AI solutions. it provides a collection of powerful components and state-of-the-art capabilities that run entirely locally on your machine. we focused on efficient implementations that deliver high performance even on modest hardware.

for complete documentation, visit [docs.srswti.com](https://docs.srswti.com). visit [srswti.com](https://www.srswti.com) for our products, and check out our [blog](https://www.srswti.com/blogs) to learn more about our mission and the mathematical foundations behind our work.

## Key features
- local intelligence—too cheap to meter, firewall-protected for privacy, on-premise steerable, and rendering benchmarks obsolete
- everything what llms do but much faster, averaging 50-100ms latency
- industry-ready
- zero-shot classification <70ms latency
- advanced text cleaning and preprocessing
- intelligent text analysis and ner
- document clustering and ranking
- neural-probabilistic hybrid search
- multi-strategy document merging
- multilingual translation support
- sentiment analysis


## Installation

### Requirements
- Python 3.9 - 3.11

### Setting up Virtual Environment
```bash
# Create a new virtual environment using uv
uv venv --python 3.9
```

# Activate the virtual environment
```bash
# On Unix/macOS
source .venv/bin/activate
# On Windows
.venv\Scripts\activate
```

### Installing the Package
```bash
# Using uv
uv pip install srswti-axis
or 
pip install srswti-axis
```

### Install Required Dependencies
```bash
# Inside activated virtual environment
srswti-axis-post-install 
```
